@@ -189,17 +189,9 @@ class VariableClBuilderVideodrvSet(IsoTypeHelper, Variable):
         self.label = _("Include proprietary video drivers")
         self.help = _("include proprietary video drivers")
 
-    def set(self, value):
-        if value == 'auto' or value is None:
-            self.value = "on" if self.Get('os_builder_linux_system') == "desktop" else "off"
-        else:
-            self.value = value
-        return self.value
-
     def get(self):
         if not self.value or self.value == 'auto':
-            self.set('auto')
-            return self.value
+            self.autodetect = True
         if self.autodetect:
             fn = self.Get('cl_builder_video_driver_path')
             return "on" if path.exists(fn) else "off"
