@@ -335,13 +335,10 @@ class VariableOsBuilderLinuxFullname(ReadonlyVariable):
     def get(self):
         name = self.Get('os_builder_linux_name')
         subname = self.Get('os_builder_linux_subname')
-        if subname:
-            subname = " %s" % subname
         ver = self.Get('os_builder_linux_ver')
         build = self.Get('os_builder_linux_build')
         arch = self.Get('os_builder_arch_machine')
-        return self.fullname_format.format(
-            name=name, ver=ver, subname=subname, arch=arch, build=build)
+        return ' '.join([x for x in [name, ver, subname, arch, build] if x])
 
 
 class VariableOsBuilderLinuxSubname(BuilderLinux):
